#
# spec file for package ghc-yesod-persistent
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name yesod-persistent
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.6.0.8
Release:        2.86
Summary:        Some helpers for using Persistent from Yesod
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Patch0:         https://github.com/yesodweb/yesod/pull/1798.patch#/dont-depend-on-obsolete-persistent-template.patch
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-blaze-builder-devel
BuildRequires:  ghc-blaze-builder-prof
BuildRequires:  ghc-conduit-devel
BuildRequires:  ghc-conduit-prof
BuildRequires:  ghc-persistent-devel
BuildRequires:  ghc-persistent-prof
BuildRequires:  ghc-resource-pool-devel
BuildRequires:  ghc-resource-pool-prof
BuildRequires:  ghc-resourcet-devel
BuildRequires:  ghc-resourcet-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
BuildRequires:  ghc-yesod-core-devel
BuildRequires:  ghc-yesod-core-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-prof
BuildRequires:  ghc-persistent-sqlite-devel
BuildRequires:  ghc-persistent-sqlite-prof
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-wai-extra-devel
BuildRequires:  ghc-wai-extra-prof
%endif

%description
API docs and the README are available at
<http://www.stackage.org/package/yesod-persistent>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
- Apply "dont-depend-on-obsolete-persistent-template.patch" to avoid
  depending on the obsolete persistent-templates package.
* Fri Apr 15 2022 Peter Simons <psimons@suse.com>
- Update yesod-persistent to version 1.6.0.8.
  [#]# 1.6.0.8
  * Add support for `persistent-2.14` [#1706](https://github.com/yesodweb/yesod/pull/1760)
* Fri May  7 2021 psimons@suse.com
- Update yesod-persistent to version 1.6.0.7.
  [#]# 1.6.0.7
  * Add support for persistent 2.13. [#1723](https://github.com/yesodweb/yesod/pull/1723)
* Wed Mar 31 2021 psimons@suse.com
- Update yesod-persistent to version 1.6.0.6.
  [#]# 1.6.0.6
  * Add support for persistent 2.12
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Sat Nov  7 2020 psimons@suse.com
- Update yesod-persistent to version 1.6.0.5.
  [#]# 1.6.0.5
  * Add support for Persistent 2.11 [#1701](https://github.com/yesodweb/yesod/pull/1701)
* Wed Aug 19 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Add _constraints with min 6GB disk space for ppc64/ppc64le
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun  9 2020 psimons@suse.com
- Add yesod-persistent at version 1.6.0.4.
